@@ -70,6 +70,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
         'packages_enabled',
         'wiki_access_level',
         'snippets_access_level',
+        'squash_option',
         'pages_access_level',
         'emails_disabled',
         # 'show_default_award_emojis',  # FIXME Gitlab
@@ -295,6 +296,11 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                 'description': 'Snippets access level.',
                 'enum': ['disabled', 'private', 'enabled'],
             },
+            'squash_option': {
+                'type': 'string',
+                'description': 'Squash option.',
+                'enum': ['never', 'always', 'default_on', 'default_off'],
+            },
             'pages_access_level': {
                 'type': 'string',
                 'description': 'Forking access level.',
@@ -475,7 +481,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
             # From https://docs.gitlab.com/ee/api/projects.html#edit-project
             'default_branch': {
                 'type': 'string',
-                'description': '`master` by default',
+                'description': 'The default branch name',
             },
             'autoclose_referenced_issues': {
                 'type': 'boolean',
@@ -558,12 +564,12 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                              '      branches: # if you omit this parameter, all branches are mirrored\n'
                              "        - from: '/wip-.*/'\n"
                              "          to: '' # This will skip those branches\n"
-                             '        - from: master\n'
-                             '          # to: master # implicitly equal to source branch\n'
+                             '        - from: main\n'
+                             '          # to: main # implicitly equal to source branch\n'
                              # '          # skip_ci: false # inherited by default \n'
                              # '          merge_request: true  '
                              # '# Will create a temporary branch and create '
-                             # 'a MR targeting master (the `to` parameter)\n'
+                             # 'a MR targeting main (the `to` parameter)\n'
                              # '          merge_request_from_fork: myself/myproject # will fork if needed\n'
                              '        # Using regexps\n'
                              "        - from: '/(.*)/'\n"
@@ -623,7 +629,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                     },
                 },
                 '_example': ('\n'
-                             '    master:\n'
+                             '    main:\n'
                              '      merge_access_level: maintainer # one of noone, developer, maintainer\n'
                              '      push_access_level: noone\n'
                              '    develop:\n'
@@ -663,7 +669,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                 },
                 'uniqueItems': True,
                 '_example': ('\n'
-                             '    - master\n'
+                             '    - main\n'
                              '    - develop'),
             },
             'rename_branches': {
@@ -812,7 +818,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                              '    enabled: true\n'
                              '    cadence: 7d # 1d, 7d, 14d, 1month, 3month\n'
                              '    keep_n: 10 # 1, 5, 10, 25, 50, 100\n'
-                             "    name_regex_keep: '.*master|.*release|release-.*|master-.*'\n"
+                             "    name_regex_keep: '.*main|.*release|release-.*|main-.*'\n"
                              '    older_than: 90d\n'
                              "    name_regex_delete: '.*'\n"),
             },
@@ -1042,7 +1048,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                 'uniqueItems': True,
                 '_example': ('\n'
                              '    - description: Build packages\n'
-                             '      ref: master\n'
+                             '      ref: main\n'
                              "      cron: '0 1 * * 5'\n"
                              '      # cron_timezone: UTC\n'
                              '      # active: true\n'
@@ -1234,6 +1240,71 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                             },
                             'additionalProperties': False,
                         },
+                        {
+                            'type': 'object',
+                            'description': 'Helm source',
+                            'properties': {
+                                'helm': {
+                                    'type': 'object',
+                                    'properties': {
+                                        'repo_url': {
+                                            'type': 'string',
+                                        },
+                                        'package_name': {
+                                            'type': 'string',
+                                        },
+                                        'versions': {
+                                            'type': 'array',
+                                            'items': {
+                                                'type': 'string',
+                                            },
+                                        },
+                                        'semver': {
+                                            'type': 'string',
+                                        },
+                                        'limit': {
+                                            'type': 'integer',
+                                        },
+                                        'channel': {
+                                            'type': 'string',
+                                        },
+                                    },
+                                    'required': ['repo_url', 'package_name'],
+                                    'additionalProperties': False,
+                                },
+                            },
+                            'additionalProperties': False,
+                        },
+                        {
+                            'type': 'object',
+                            'description': 'PyPI source',
+                            'properties': {
+                                'pypi': {
+                                    'type': 'object',
+                                    'properties': {
+                                        'index_url': {
+                                            'type': 'string',
+                                        },
+                                        'requirements': {
+                                            'oneOf': [
+                                                {
+                                                    'type': 'string',
+                                                },
+                                                {
+                                                    'type': 'array',
+                                                    'items': {
+                                                        'type': 'string',
+                                                    },
+                                                },
+                                            ],
+                                        },
+                                    },
+                                    'required': ['requirements'],
+                                    'additionalProperties': False,
+                                },
+                            },
+                            'additionalProperties': False,
+                        },
                     ],
                 },
                 '_example': ('\n'
