@@ -350,7 +350,7 @@ class TestProjectImageMirrors(TestCaseWithManager):
                     'v0.1.0',
                     '1+0=1 uploaded+existing manifests',
                     '4+0+3=7 uploaded+mounted+existing blobs',
-                    '56+0+42=98 uploaded+mounted+existing blobs size',  # 14173208+0+96=14173304
+                    '-4+0+-3=-7 uploaded+mounted+existing blobs size',  # 14173208+0+96=14173304
                 )])
 
     @my_vcr.use_cassette
@@ -385,6 +385,37 @@ class TestProjectImageMirrors(TestCaseWithManager):
                 )])
         self.assertTrue(cass.all_played)
 
+    @my_vcr.use_cassette
+    def test_image_mirrors_redirect(self, cass):
+        """Test image_mirrors, with redirect.
+
+        Args:
+            cass: VCR cassette.
+        """
+        expected_digest = 'sha256:4fd21f36075b44d1a423dfb262ad79202ce54e95f5cbc4622a6c1c38ab287ad6'
+        with patch.object(WithDigest, VERIFY_DIGEST_METHOD) as verify_digest_mock:
+            verify_digest_mock.return_value = None
+            project = GitLabracadabraProject('memory', 'root/test-registry', {
+                'image_mirrors': [
+                    {'from': 'registry.k8s.io/sig-storage/csi-node-driver-registrar:v2.5.0'},
+                ],
+            })
+            self.assertEqual(project.errors(), [])
+            with patch('gitlabracadabra.containers.registry_importer.logger', autospec=True) as logger:
+                project.process()
+                logger.info.assert_has_calls([call(
+                    '%s%s %simported as %s:%s (%s, %s, %s)',
+                    '[root/test-registry] ',
+                    'registry.k8s.io/sig-storage/csi-node-driver-registrar:v2.5.0@{0}'.format(expected_digest),
+                    '',
+                    'root/test-registry/sig-storage/csi-node-driver-registrar',
+                    'v2.5.0',
+                    '1+0=1 uploaded+existing manifests',
+                    '3+0+0=3 uploaded+mounted+existing blobs',
+                    '9128096+0+0=9128096 uploaded+mounted+existing blobs size',
+                )])
+        self.assertTrue(cass.all_played)
+
     def _assert_mappings(self, registry, import_manifest_mock, mappings):
         self.assertEqual(len(import_manifest_mock.mock_calls), len(mappings))
         for mapping_index, mapping in enumerate(mappings):
